# pythonprotools
Módulo usado para aprender a construção e contribuição  de projetos de código aberto - Pytools

[Link Projeto](https://github.com/italodg9/pythonprotools)

Suportada para versão 3 de Python

Para instalar:
```
python3 -m venv .venv
source .venv\Sripts\activate
pip install requirements-dev.txt
```

Para conferir a qualidade:
````
flake8
````


Tópicos abordados:
1. Git
2. Virtualenv
3. Pip

